use clap::Parser;

mod cli;

fn main() -> anyhow::Result<()> {
    let cli = cli::CliArgs::parse();
    
    std::env::set_var("RUST_LOG", "debug");
    env_logger::init();
    
    let mut parser = bfox_parser::Parser::new();

    let Ok(input_code) = std::fs::read_to_string(&cli.input) else {
        log::error!("Couldnt read input file: {}", cli.input);
        return Ok(());
    };

    parser.parse(input_code, cli.input.to_string())?;

    let tokens = parser.tokens();

    log::debug!("{tokens:?}");

    let mut asmgen = bfox_asmgen::AsmGen::new();

    asmgen.set_asm_type(cli.target);

    asmgen.generate(tokens.to_vec(), cli.input.into_std_path_buf())?;

    if cli.assemly {
        //TODO: Compile here

    }

    Ok(())
}
